#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_HJMIN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_HJMIN_HPP_INCLUDED

#include <nt2/optimization/include/functions/scalar/hjmin.hpp>

#endif
